@@ -135,185 +135,6 @@ class DVPOAuth:
         return True if resp["d"]["ZDSMInquiry"]["RejectionReasonDsm"] == "" else False
 
     def convert_account_retrieve_from_oauth_to_soap(self, status_code=None, resp=None):
-# resp = 
-# {
-#    "__metadata":{
-#       "id":"http://sapiuqapp01.dominionnet.com:8001/sap/opu/odata/sap/ZISU_UMC_DSM_SRV/ZAcctSearchAndRetrieveSet('RETRACCT')",
-#       "uri":"http://sapiuqapp01.dominionnet.com:8001/sap/opu/odata/sap/ZISU_UMC_DSM_SRV/ZAcctSearchAndRetrieveSet('RETRACCT')",
-#       "type":"ZISU_UMC_DSM_SRV.ZAcctSearchAndRetrieve"
-#    },
-#    "RETRACCTData":{
-#       "__metadata":{
-#          "type":"ZISU_UMC_DSM_SRV.RetrAcctData"
-#       },
-#       "AccountClass":"Z001",
-#       "AccountCloseDate":"None",
-#       "AccountRepFlag":"",
-#       "AccountRepName":"",
-#       "AccountActive":"Y",
-#       "AccountType":"MM",
-#       "AcctOpenDate":"/Date(1661817600000)/",
-#       "ActivityTimestamp":"/Date(1676927897000)/",
-#       "AdditionalAddressInfo":"",
-#       "AlternateRate":"",
-#       "AltMailAddrSeq":"",
-#       "BillAccountStatusCode":"A",
-#       "BillCycle":"01",
-#       "CodeNpso":"",
-#       "CollectionAgencyStatus":"",
-#       "CurrentConversationId":"",
-#       "CustomerId":"1102679581",
-#       "CustomerName1":"DAVID ALLEN ASHLEY",
-#       "CustomerName2":"",
-#       "CustomerName3":"",
-#       "CustomerName4":"",
-#       "CustomerName5":"",
-#       "CustomerPin1":"",
-#       "CustomerPin2":"",
-#       "CustomerPin3":"",
-#       "CustomerPin4":"",
-#       "CustomerPin5":"",
-#       "CustomerSsn1":"7815",
-#       "CustomerSsn2":"",
-#       "CustomerSsn3":"",
-#       "CustomerSsn4":"",
-#       "CustomerSsn5":"",
-#       "DateEndMm":"",
-#       "DateEndYyyy":"",
-#       "DateStartMm":"",
-#       "DateStartYyyy":"",
-#       "DelinquencyIndicator":"N",
-#       "FederalTaxId":"",
-#       "InternetUserId":"",
-#       "MailAddrCity":"POWHATAN",
-#       "MailAddrDateEffective":"None",
-#       "MailAddrDateTerm":"None",
-#       "MailAddrDirection":"",
-#       "MailAddrDirSuffix":"",
-#       "MailAddrHouseMod":"",
-#       "MailAddrHouseNumber":"3845",
-#       "MailAddrModifier":"",
-#       "MailAddrName":"",
-#       "MailAddrNonStd1":"",
-#       "MailAddrNonStd2":"",
-#       "MailAddrNonStd3":"",
-#       "MailAddrState":"VA",
-#       "MailAddrStreetName":"WILDWOOD SHORES CT",
-#       "MailAddrStreetType":"",
-#       "MailAddrZipcode":"23139",
-#       "MailAddrZipSuffix":"7071",
-#       "NameCustFirst":"DAVID",
-#       "NameCustLast":"ASHLEY",
-#       "NameCustMiddle":"ALLEN",
-#       "Password":"",
-#       "PasswordIndicator":"N",
-#       "Phone":"",
-#       "PhoneAreaCode":"",
-#       "PhoneExt":"",
-#       "PhoneNumberSeq":"",
-#       "PremiseId":"0088149407",
-#       "RateCode":"VR-1",
-#       "RateCodeDescription":"VA Resi Sch-1",
-#       "RevenueClass":"",
-#       "ServicePointId":"7002804335",
-#       "ServicePointSpecialUse":"",
-#       "SpecialContractDemand":"",
-#       "SvcAddrCardinalDir":"",
-#       "SvcAddrCity":"POWHATAN",
-#       "SvcAddrCountry":"US",
-#       "SvcAddrDirSuffix":"",
-#       "SvcAddrHouse":"3845",
-#       "SvcAddrHouseMod":"",
-#       "SvcAddrModifier":"",
-#       "SvcAddrSt":"VA",
-#       "SvcAddrStreetName":"WILDWOOD SHORES CT",
-#       "SvcAddrStreetSuffix":"",
-#       "SvcAddrZip":"23139",
-#       "SvcAddrZipSuffix":"7071",
-#       "TerminalId":"",
-#       "TownCode":"0500",
-#       "Contract":"",
-#       "UserId":"",
-#       "MailingAddress":{
-#          "__metadata":{
-#             "type":"ZISU_UMC_DSM_SRV.ZContractAccMaintMailAdress"
-#          },
-#          "CareOf":"",
-#          "City":"POWHATAN",
-#          "Country":"US",
-#          "HouseNum1":"3845",
-#          "HouseNum2":"",
-#          "InternationAddrx":"",
-#          "Location":"",
-#          "MailingaddrType":"ST",
-#          "PoBoxAdress":"",
-#          "Region":"VA",
-#          "Street":"WILDWOOD SHORES CT",
-#          "ZipCode":"23139-7071",
-#          "InternationAddr":{
-#             "__metadata":{
-#                "type":"ZISU_UMC_DSM_SRV.ZmailingAddr"
-#             },
-#             "Line1":"",
-#             "Line2":"",
-#             "Line3":"",
-#             "Line4":"",
-#             "Line5":"",
-#             "Line6":""
-#          }
-#       }
-#    },
-#    "SearchType":"",
-#    "InternetFunctionCode":"RETRACCT",
-#    "UserId":"",
-#    "CallingApplication":"",
-#    "QuantityRowsRequested":0,
-#    "AreaCode":"",
-#    "PhoneNumber":"",
-#    "Email":"",
-#    "OfficeCode":"",
-#    "TownCode":"",
-#    "CustomerFirstName":"",
-#    "CustomerMidName":"",
-#    "CustomerLastName":"",
-#    "CorporateName":"",
-#    "HouseNumber":"",
-#    "HouseNumberMod":"",
-#    "CardinalDirection":"",
-#    "StreetName":"",
-#    "StreetType":"",
-#    "DirectionSuffix":"",
-#    "AddressModifier":"",
-#    "City":"",
-#    "State":"",
-#    "Zip":"",
-#    "Meter":"",
-#    "Premise":"",
-#    "FederalTaxId":"",
-#    "SSN":"",
-#    "Pin":"",
-#    "BusinessPartner":"",
-#    "BillAccount":"000889103594",
-#    "ActiveBaOnly":"",
-#    "ServiceAccountsOnly":"",
-#    "InternetReturnCode":"S",
-#    "ReturnMessageText":"Business Account details retrived successfully!",
-#    "ResultCode":"00",
-#    "ErrorCode":"",
-#    "ActiveTimeStamp":"/Date(1676927897000)/",
-#    "MoreData":"N",
-#    "RowsReturned":1,
-#    "ZAcctSearchNav":{
-#       "results":[
-         
-#       ]
-#    },
-#    "ZRetrContractsNav":{
-#       "__deferred":{
-#          "uri":"http://sapiuqapp01.dominionnet.com:8001/sap/opu/odata/sap/ZISU_UMC_DSM_SRV/ZAcctSearchAndRetrieveSet('RETRACCT')/ZRetrContractsNav"
-#       }
-#    }
-# }
         data = resp['d']['results'][0]
         res = {
             'AccountNumber': data['BillAccount'],
@@ -356,7 +177,7 @@ class DVPOAuth:
                     {
                         'AmiMeter': None,
                         'MeterNumber': None,
-                        'RateCode': None,
+                        'RateCode': data['RETRACCTData']['RateCode'],
                     }
                 ]
             },
@@ -468,6 +289,8 @@ class DVPOAuth:
                     "CompanyNumber": "",
                     "State": data["State"],
                     "ZipCode": data["Zip"],
+                    "Premise": data["Premise"],
+                    "Meter": data["MeterId"]
                 }
             )
         
@@ -527,7 +350,7 @@ class DVPOAuth:
                     SEARCH_PAR
                     + "SearchType eq 'MET' and Meter eq '"
                     + dict["meter_number"]
-                    + "' and ActiveBaOnly eq 'Y'"
+                    + "' and ActiveBaOnly eq 'Y' and QuantityRowsRequested eq 50"
                 )
             elif dict["premise_number"]:
                 filter = (
